@@ -11,6 +11,7 @@ import re
 import subprocess
 import sys
 import unittest
+from contextlib import contextmanager
 
 from llvmlite import six, ir
 from llvmlite import binding as llvm
@@ -163,6 +164,7 @@ class TestDependencies(BaseTest):
     """
 
     @unittest.skipUnless(sys.platform.startswith('linux'), "Linux-specific test")
+    @unittest.skipUnless(os.environ.get('LLVMLITE_DIST_TEST'), "Distribution-specific test")
     def test_linux(self):
         lib_path = ffi.lib._name
         env = os.environ.copy()
@@ -187,7 +189,10 @@ class TestDependencies(BaseTest):
             self.fail("failed parsing dependencies? got %r" % (deps,))
         # Ensure all dependencies are expected
         allowed = set(['librt', 'libdl', 'libpthread', 'libz', 'libm',
-                       'libgcc_s', 'libc', 'ld-linux'])
+                       'libgcc_s', 'libc', 'ld-linux', 'ld64'])
+        if platform.python_implementation() == 'PyPy':
+            allowed.add('libtinfo')
+
         for dep in deps:
             if not dep.startswith('ld-linux-') and dep not in allowed:
                 self.fail("unexpected dependency %r in %r" % (dep, deps))
@@ -292,7 +297,7 @@ class TestMisc(BaseTest):
 
     def test_version(self):
         major, minor, patch = llvm.llvm_version_info
-        self.assertEqual((major, minor), (3, 9))
+        self.assertEqual((major, minor), (4, 0))
         self.assertIn(patch, range(10))
 
     def test_check_jit_execution(self):
@@ -889,6 +894,20 @@ class TestPassManagerBuilder(BaseTest):
             pmb.disable_unroll_loops = b
             self.assertEqual(pmb.disable_unroll_loops, b)
 
+    def test_loop_vectorize(self):
+        pmb = self.pmb()
+        self.assertIsInstance(pmb.loop_vectorize, bool)
+        for b in (True, False):
+            pmb.loop_vectorize = b
+            self.assertEqual(pmb.loop_vectorize, b)
+
+    def test_slp_vectorize(self):
+        pmb = self.pmb()
+        self.assertIsInstance(pmb.slp_vectorize, bool)
+        for b in (True, False):
+            pmb.slp_vectorize = b
+            self.assertEqual(pmb.slp_vectorize, b)
+
     def test_populate_module_pass_manager(self):
         pmb = self.pmb()
         pm = llvm.create_module_pass_manager()
@@ -1042,6 +1061,34 @@ class TestAnalysis(BaseTest):
         self.assertNotIn(inst, dot_without_inst)
 
 
+class TestTypeParsing(BaseTest):
+    @contextmanager
+    def check_parsing(self):
+        mod = ir.Module()
+        # Yield to caller and provide the module for adding
+        # new GV.
+        yield mod
+        # Caller yield back and continue with testing
+        asm = str(mod)
+        llvm.parse_assembly(asm)
+
+    def test_literal_struct(self):
+        # Natural layout
+        with self.check_parsing() as mod:
+            typ = ir.LiteralStructType([ir.IntType(32)])
+            gv = ir.GlobalVariable(mod, typ, "foo")
+            # Also test constant text repr
+            gv.initializer = ir.Constant(typ, [1])
+
+        # Packed layout
+        with self.check_parsing() as mod:
+            typ = ir.LiteralStructType([ir.IntType(32)],
+                                       packed=True)
+            gv = ir.GlobalVariable(mod, typ, "foo")
+            # Also test constant text repr
+            gv.initializer = ir.Constant(typ, [1])
+
+
 class TestGlobalVariables(BaseTest):
     def check_global_variable_linkage(self, linkage, has_undef=True):
         # This test default initializer on global variables with different
