@@ -412,7 +412,8 @@ class TestGlobalValues(TestBase):
         globdouble = ir.GlobalVariable(mod, ir.DoubleType(), 'globdouble')
         self.assertEqual(mod.get_global('foo'), foo)
         self.assertEqual(mod.get_global('globdouble'), globdouble)
-        self.assertIsNone(mod.get_global('kkk'))
+        with self.assertRaises(KeyError):
+            mod.get_global('kkk')
         # Globals should have a useful repr()
         self.assertEqual(repr(globdouble),
                          "<ir.GlobalVariable 'globdouble' of type 'double*'>")
@@ -799,6 +800,61 @@ class TestBuildInstructions(TestBase):
             """)
         # XXX test with more complex types
 
+    def test_gep_castinstr(self):
+        # similar to:
+        # numba::runtime::nrtdynmod.py_define_nrt_meminfo_data()
+        block = self.block(name='my_block')
+        builder = ir.IRBuilder(block)
+        a, b = builder.function.args[:2]
+        int8ptr = int8.as_pointer()
+        ls = ir.LiteralStructType([int64, int8ptr, int8ptr, int8ptr, int64])
+        d = builder.bitcast(a, ls.as_pointer(), name='d')
+        e = builder.gep(d, [ir.Constant(int32, x) for x in [0, 3]], name='e')
+        self.assertEqual(e.type, ir.PointerType(int8ptr))
+        self.check_block(block, """\
+            my_block:
+                %"d" = bitcast i32 %".1" to {i64, i8*, i8*, i8*, i64}*
+                %"e" = getelementptr {i64, i8*, i8*, i8*, i64}, {i64, i8*, i8*, i8*, i64}* %"d", i32 0, i32 3
+            """)
+
+    def test_gep_castinstr_addrspace(self):
+        # similar to:
+        # numba::runtime::nrtdynmod.py_define_nrt_meminfo_data()
+        block = self.block(name='my_block')
+        builder = ir.IRBuilder(block)
+        a, b = builder.function.args[:2]
+        addrspace = 4
+        int8ptr = int8.as_pointer()
+        ls = ir.LiteralStructType([int64, int8ptr, int8ptr, int8ptr, int64])
+        d = builder.bitcast(a, ls.as_pointer(addrspace=addrspace), name='d')
+        e = builder.gep(d, [ir.Constant(int32, x) for x in [0, 3]], name='e')
+        self.assertEqual(e.type.addrspace, addrspace)
+        self.assertEqual(e.type, ir.PointerType(int8ptr, addrspace=addrspace))
+        self.check_block(block, """\
+            my_block:
+                %"d" = bitcast i32 %".1" to {i64, i8*, i8*, i8*, i64} addrspace(4)*
+                %"e" = getelementptr {i64, i8*, i8*, i8*, i64}, {i64, i8*, i8*, i8*, i64} addrspace(4)* %"d", i32 0, i32 3
+            """)
+
+    def test_gep_addrspace(self):
+        block = self.block(name='my_block')
+        builder = ir.IRBuilder(block)
+        a, b = builder.function.args[:2]
+        addrspace = 4
+        c = builder.alloca(ir.PointerType(int32, addrspace=addrspace), name='c')
+        self.assertEqual(str(c.type), 'i32 addrspace(4)**')
+        self.assertEqual(c.type.pointee.addrspace, addrspace)
+        d = builder.gep(c, [ir.Constant(int32, 5), a], name='d')
+        self.assertEqual(d.type.addrspace, addrspace)
+        e = builder.gep(d, [ir.Constant(int32, 10)], name='e')
+        self.assertEqual(e.type.addrspace, addrspace)
+        self.check_block(block, """\
+            my_block:
+                %"c" = alloca i32 addrspace(4)*
+                %"d" = getelementptr i32 addrspace(4)*, i32 addrspace(4)** %"c", i32 5, i32 %".1"
+                %"e" = getelementptr i32, i32 addrspace(4)* %"d", i32 10
+            """)
+
     def test_extract_insert_value(self):
         block = self.block(name='my_block')
         builder = ir.IRBuilder(block)
@@ -1434,6 +1490,10 @@ class TestTypes(TestBase):
         self.assertEqual(str(ir.LiteralStructType((
             ir.PointerType(int1), ir.LiteralStructType((int32, int8))))),
             '{i1*, {i32, i8}}')
+        self.assertEqual(str(ir.LiteralStructType((int1,), packed=True)),
+                         '<{i1}>')
+        self.assertEqual(str(ir.LiteralStructType((int1,flt), packed=True)),
+                         '<{i1, float}>')
 
         # Avoid polluting the namespace
         context = ir.Context()
@@ -1444,6 +1504,10 @@ class TestTypes(TestBase):
         mytype2 = context.get_identified_type("MyType\"")
         self.assertEqual(str(mytype2), "%\"MyType\\22\"")
 
+    def test_hash(self):
+        for typ in filter(self.has_logical_equality, self.assorted_types()):
+            self.assertEqual(hash(typ), hash(copy.copy(typ)))
+
     def test_gep(self):
         def check_constant(tp, i, expected):
             actual = tp.gep(ir.Constant(int32, i))
@@ -1676,6 +1740,19 @@ class TestConstant(TestBase):
             'getelementptr ({float, i1}, {float, i1}* @"myconstant", i32 0, i32 1)')
         self.assertEqual(c.type, ir.PointerType(int1))
 
+    def test_gep_addrspace_globalvar(self):
+        m = self.module()
+        tp = ir.LiteralStructType((flt, int1))
+        addrspace = 4
+
+        gv = ir.GlobalVariable(m, tp, "myconstant", addrspace=addrspace)
+        self.assertEqual(gv.addrspace, addrspace)
+        c = gv.gep([ir.Constant(int32, x) for x in (0, 1)])
+        self.assertEqual(c.type.addrspace, addrspace)
+        self.assertEqual(str(c),
+            'getelementptr ({float, i1}, {float, i1} addrspace(4)* @"myconstant", i32 0, i32 1)')
+        self.assertEqual(c.type, ir.PointerType(int1, addrspace=addrspace))
+
     def test_bitcast(self):
         m = self.module()
         gv = ir.GlobalVariable(m, int32, "myconstant")
